import Vue from 'vue';
import Vuex from 'vuex';
import persistedState from 'vuex-persistedstate';

Vue.use(Vuex);

const store = new Vuex.Store({
	plugins: [
		persistedState()
	],
	state: {
		carts: [],
		user: null
	},
	getters: {
		count(state) {
			return (id) => {
				let index = state.carts.findIndex(v => v.id == id)
				if (index == -1) {
					return 0
				} else {
					return state.carts[index].count
				}
			}
		}
	},
	mutations: {
		add(state, cart) {
			let index = state.carts.findIndex(v => v.id == cart.id)
			if (index == -1) {
				state.carts.push(cart)
			} else {
				state.carts[index].count += cart.count
			}
		},
		sub(state, cart) {
			let index = state.carts.findIndex(v => v.id == cart.id)
			if (index != -1) {
				if (state.carts[index].count > 1) {
					state.carts[index].count -= 1
				} else {
					state.carts.splice(index, 1)
				}
			}
		},
		user(state, user) {
			state.user = user
		}
	},
	actions: {
		add(context, cart) {
			context.commit('add', cart)
		},
		sub(context, cart) {
			context.commit('sub', cart)
		},
		user(context, user) {
			context.commit('user', user)
		}
	}
});
export default store;
